==> pmml-model-1.1.9-sources.jar: org/dmg/pmml/BinarySimilarity.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_2}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="c00-parameter" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="c01-parameter" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="c10-parameter" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="c11-parameter" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="d00-parameter" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="d01-parameter" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="d10-parameter" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *       &lt;attribute name="d11-parameter" use="required" type="{http://www.dmg.org/PMML-4_2}NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "binarySimilarity", namespace = "http://www.dmg.org/PMML-4_2")
public class BinarySimilarity
    extends Measure
    implements Locatable, HasExtensions
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_2")
    protected List<Extension> extensions;
    @XmlAttribute(name = "c00-parameter", required = true)
    protected double c00Parameter;
    @XmlAttribute(name = "c01-parameter", required = true)
    protected double c01Parameter;
    @XmlAttribute(name = "c10-parameter", required = true)
    protected double c10Parameter;
    @XmlAttribute(name = "c11-parameter", required = true)
    protected double c11Parameter;
    @XmlAttribute(name = "d00-parameter", required = true)
    protected double d00Parameter;
    @XmlAttribute(name = "d01-parameter", required = true)
    protected double d01Parameter;
    @XmlAttribute(name = "d10-parameter", required = true)
    protected double d10Parameter;
    @XmlAttribute(name = "d11-parameter", required = true)
    protected double d11Parameter;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    public BinarySimilarity() {
        super();
    }

    public BinarySimilarity(final double c00Parameter, final double c01Parameter, final double c10Parameter, final double c11Parameter, final double d00Parameter, final double d01Parameter, final double d10Parameter, final double d11Parameter) {
        super();
        this.c00Parameter = c00Parameter;
        this.c01Parameter = c01Parameter;
        this.c10Parameter = c10Parameter;
        this.c11Parameter = c11Parameter;
        this.d00Parameter = d00Parameter;
        this.d01Parameter = d01Parameter;
        this.d10Parameter = d10Parameter;
        this.d11Parameter = d11Parameter;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the c00Parameter property.
     * 
     */
    public double getC00Parameter() {
        return c00Parameter;
    }

    /**
     * Sets the value of the c00Parameter property.
     * 
     */
    public void setC00Parameter(double value) {
        this.c00Parameter = value;
    }

    /**
     * Gets the value of the c01Parameter property.
     * 
     */
    public double getC01Parameter() {
        return c01Parameter;
    }

    /**
     * Sets the value of the c01Parameter property.
     * 
     */
    public void setC01Parameter(double value) {
        this.c01Parameter = value;
    }

    /**
     * Gets the value of the c10Parameter property.
     * 
     */
    public double getC10Parameter() {
        return c10Parameter;
    }

    /**
     * Sets the value of the c10Parameter property.
     * 
     */
    public void setC10Parameter(double value) {
        this.c10Parameter = value;
    }

    /**
     * Gets the value of the c11Parameter property.
     * 
     */
    public double getC11Parameter() {
        return c11Parameter;
    }

    /**
     * Sets the value of the c11Parameter property.
     * 
     */
    public void setC11Parameter(double value) {
        this.c11Parameter = value;
    }

    /**
     * Gets the value of the d00Parameter property.
     * 
     */
    public double getD00Parameter() {
        return d00Parameter;
    }

    /**
     * Sets the value of the d00Parameter property.
     * 
     */
    public void setD00Parameter(double value) {
        this.d00Parameter = value;
    }

    /**
     * Gets the value of the d01Parameter property.
     * 
     */
    public double getD01Parameter() {
        return d01Parameter;
    }

    /**
     * Sets the value of the d01Parameter property.
     * 
     */
    public void setD01Parameter(double value) {
        this.d01Parameter = value;
    }

    /**
     * Gets the value of the d10Parameter property.
     * 
     */
    public double getD10Parameter() {
        return d10Parameter;
    }

    /**
     * Sets the value of the d10Parameter property.
     * 
     */
    public void setD10Parameter(double value) {
        this.d10Parameter = value;
    }

    /**
     * Gets the value of the d11Parameter property.
     * 
     */
    public double getD11Parameter() {
        return d11Parameter;
    }

    /**
     * Sets the value of the d11Parameter property.
     * 
     */
    public void setD11Parameter(double value) {
        this.d11Parameter = value;
    }

    public BinarySimilarity withExtensions(Extension... values) {
        if (values!= null) {
            for (Extension value: values) {
                getExtensions().add(value);
            }
        }
        return this;
    }

    public BinarySimilarity withExtensions(Collection<Extension> values) {
        if (values!= null) {
            getExtensions().addAll(values);
        }
        return this;
    }

    public BinarySimilarity withC00Parameter(double value) {
        setC00Parameter(value);
        return this;
    }

    public BinarySimilarity withC01Parameter(double value) {
        setC01Parameter(value);
        return this;
    }

    public BinarySimilarity withC10Parameter(double value) {
        setC10Parameter(value);
        return this;
    }

    public BinarySimilarity withC11Parameter(double value) {
        setC11Parameter(value);
        return this;
    }

    public BinarySimilarity withD00Parameter(double value) {
        setD00Parameter(value);
        return this;
    }

    public BinarySimilarity withD01Parameter(double value) {
        setD01Parameter(value);
        return this;
    }

    public BinarySimilarity withD10Parameter(double value) {
        setD10Parameter(value);
        return this;
    }

    public BinarySimilarity withD11Parameter(double value) {
        setD11Parameter(value);
        return this;
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        visitor.pushParent(this);
        for (int i = 0; (((status == VisitorAction.CONTINUE)&&(this.extensions!= null))&&(i<this.extensions.size())); i ++) {
            status = this.extensions.get(i).accept(visitor);
        }
        visitor.popParent();
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-1.3.2-sources.jar: org/dmg/pmml/BinarySimilarity.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="c00-parameter" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *       &lt;attribute name="c01-parameter" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *       &lt;attribute name="c10-parameter" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *       &lt;attribute name="c11-parameter" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *       &lt;attribute name="d00-parameter" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *       &lt;attribute name="d01-parameter" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *       &lt;attribute name="d10-parameter" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *       &lt;attribute name="d11-parameter" use="required" type="{http://www.dmg.org/PMML-4_3}NUMBER" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "binarySimilarity", namespace = "http://www.dmg.org/PMML-4_3")
public class BinarySimilarity
    extends Measure
    implements HasExtensions
{

    @XmlAttribute(name = "c00-parameter", required = true)
    private double c00Parameter;
    @XmlAttribute(name = "c01-parameter", required = true)
    private double c01Parameter;
    @XmlAttribute(name = "c10-parameter", required = true)
    private double c10Parameter;
    @XmlAttribute(name = "c11-parameter", required = true)
    private double c11Parameter;
    @XmlAttribute(name = "d00-parameter", required = true)
    private double d00Parameter;
    @XmlAttribute(name = "d01-parameter", required = true)
    private double d01Parameter;
    @XmlAttribute(name = "d10-parameter", required = true)
    private double d10Parameter;
    @XmlAttribute(name = "d11-parameter", required = true)
    private double d11Parameter;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;

    public BinarySimilarity() {
        super();
    }

    public BinarySimilarity(final double c00Parameter, final double c01Parameter, final double c10Parameter, final double c11Parameter, final double d00Parameter, final double d01Parameter, final double d10Parameter, final double d11Parameter) {
        super();
        this.c00Parameter = c00Parameter;
        this.c01Parameter = c01Parameter;
        this.c10Parameter = c10Parameter;
        this.c11Parameter = c11Parameter;
        this.d00Parameter = d00Parameter;
        this.d01Parameter = d01Parameter;
        this.d10Parameter = d10Parameter;
        this.d11Parameter = d11Parameter;
    }

    /**
     * Gets the value of the c00Parameter property.
     * 
     */
    public double getC00Parameter() {
        return c00Parameter;
    }

    /**
     * Sets the value of the c00Parameter property.
     * 
     */
    public BinarySimilarity setC00Parameter(double c00Parameter) {
        this.c00Parameter = c00Parameter;
        return this;
    }

    /**
     * Gets the value of the c01Parameter property.
     * 
     */
    public double getC01Parameter() {
        return c01Parameter;
    }

    /**
     * Sets the value of the c01Parameter property.
     * 
     */
    public BinarySimilarity setC01Parameter(double c01Parameter) {
        this.c01Parameter = c01Parameter;
        return this;
    }

    /**
     * Gets the value of the c10Parameter property.
     * 
     */
    public double getC10Parameter() {
        return c10Parameter;
    }

    /**
     * Sets the value of the c10Parameter property.
     * 
     */
    public BinarySimilarity setC10Parameter(double c10Parameter) {
        this.c10Parameter = c10Parameter;
        return this;
    }

    /**
     * Gets the value of the c11Parameter property.
     * 
     */
    public double getC11Parameter() {
        return c11Parameter;
    }

    /**
     * Sets the value of the c11Parameter property.
     * 
     */
    public BinarySimilarity setC11Parameter(double c11Parameter) {
        this.c11Parameter = c11Parameter;
        return this;
    }

    /**
     * Gets the value of the d00Parameter property.
     * 
     */
    public double getD00Parameter() {
        return d00Parameter;
    }

    /**
     * Sets the value of the d00Parameter property.
     * 
     */
    public BinarySimilarity setD00Parameter(double d00Parameter) {
        this.d00Parameter = d00Parameter;
        return this;
    }

    /**
     * Gets the value of the d01Parameter property.
     * 
     */
    public double getD01Parameter() {
        return d01Parameter;
    }

    /**
     * Sets the value of the d01Parameter property.
     * 
     */
    public BinarySimilarity setD01Parameter(double d01Parameter) {
        this.d01Parameter = d01Parameter;
        return this;
    }

    /**
     * Gets the value of the d10Parameter property.
     * 
     */
    public double getD10Parameter() {
        return d10Parameter;
    }

    /**
     * Sets the value of the d10Parameter property.
     * 
     */
    public BinarySimilarity setD10Parameter(double d10Parameter) {
        this.d10Parameter = d10Parameter;
        return this;
    }

    /**
     * Gets the value of the d11Parameter property.
     * 
     */
    public double getD11Parameter() {
        return d11Parameter;
    }

    /**
     * Sets the value of the d11Parameter property.
     * 
     */
    public BinarySimilarity setD11Parameter(double d11Parameter) {
        this.d11Parameter = d11Parameter;
        return this;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public BinarySimilarity addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
